Bi-Weekly Rucio Project meeting — Rucio 0.3.8 documentation

# Bi-Weekly Rucio Project meeting

The Rucio Team holds biweekly Project & Release Status meetings:

- Monday, 14:00 to 16:00 (CERN time)
- Thursday, 09:15 to 11:00 (CERN time)

Everyone is encouraged to attend.

## Agenda for next meeting

The next meeting will be Thursday, 12.04.2012, 09:15 to 11:00, Room: 1-1-025.

## Rucio meeting notes & logs

Rucio meetings, with their notes and logs, can be found at:

- 2012

> - 2012-03-29: `project_meeting_logs/2012-03-29`
> - 2012-04-02: `project_meeting_logs/2012-04-02`